# Print This Page

## Overview
A Drupal module that provides a customizable print button block which allows
users to print the current page. The button is accessible and can be placed in
any region or entity display via the block layout or display management. The
module includes options to customize the link text, show/hide the print icon,
and exclude specific page elements from printing.

## Quick Start

### Installation
```bash
# Enable the module
drush en print_this_page -y

# Clear cache
drush cr
```

### Adding the Print Button

**Option 1: As a Block**
1. Navigate to **Structure** > **Block layout** (`/admin/structure/block`)
2. Click **Place block** in your desired region
3. Find and select **Print This Page**
4. Configure the block settings (link text, icon, exclude elements)
5. Click **Save block**

**Option 2: As a Field Formatter**
1. Navigate to 
    > **Structure** 
    > **Content types** 
    > **[Your Content Type]** 
    > **Manage display**
2. Select an existing field and change its formatter to **Print This Page**
3. Configure the formatter settings
4. Click **Save**

### Basic Configuration
- **Link Text**: Default is "Print this page" (customize as needed)
- **Show Icon**: Enabled by default (shows print icon next to text)
- **Exclude Elements**: Default excludes 
  `header, footer, aside, nav, form, iframe, .menu`

## Features
- Accessible print button with proper ARIA attributes
- Visual states for hover, focus, and active interactions
- Hidden when JavaScript is disabled to avoid confusion
- Google Analytics integration via dataLayer events
- Customizable link text
- Optional print icon display (SVG-based)
- Configurable element exclusion from printing
- Can be placed in any block region or added to entity display

## Configuration Options

### Block Configuration
When placing the Print This Page block, you can configure:

- **Link Text**: Customize the text displayed for the print link 
  (default: "Print this page")
- **Show print icon**: Toggle display of the print icon next to the text
- **Elements to exclude from printing**: Comma-separated list of CSS selectors 
  to hide when printing

### Field Formatter Settings
When using the Print This Page formatter on a field, you can configure:

- **Link Text**: Customize the text displayed for the print link
- **Show print icon**: Toggle display of the print icon next to the text
- **Elements to exclude from printing**: Comma-separated list of CSS 
  selectors to hide when printing

### Exclude Elements from Printing
You can specify CSS selectors (IDs, classes, or element names) that should be 
  hidden when printing. Common examples:
- `header, footer, aside, nav` - Hide structural elements
- `.menu, .breadcrumb` - Hide navigation elements
- `form, iframe` - Hide interactive elements
- `#sidebar, .comments` - Hide specific sections

## Technical Implementation
- **SVG Icon**: Uses a scalable SVG print icon that adapts to theme colors
- **Dynamic CSS**: Generates print-specific CSS rules to hide excluded elements
- **Progressive Enhancement**: Button only appears when JavaScript is enabled
- **Accessibility**: Includes proper ARIA labels and keyboard navigation support

## Accessibility
This module follows accessibility best practices:
- Screen reader compatible text
- Keyboard navigation support
- Focus indicators
- Touch-friendly design
- ARIA labels
- Print icon is decorative and ignored by screen readers

## Analytics Integration
The module automatically tracks print button clicks 
  via Google Analytics dataLayer if available:
```javascript
dataLayer.push({
  event: 'print_button_clicked',
  page_title: document.title,
  page_location: window.location.href,
});
```

## Customization
The button styling can be customized by overriding the CSS in your theme. 
The print icon can be replaced by updating the 
SVG file at `images/print-icon.svg`.

## Requirements
- Drupal 9, 10, or 11
- Block module (core)

## Troubleshooting

### Print Button Not Appearing
- Ensure JavaScript is enabled in the browser
- Check that the block is placed in a visible region
- Verify the module is enabled: 
  `drush pm:list --status=enabled | grep print_this_page`

### Elements Still Showing When Printing
- Check the exclude list configuration in the block/formatter settings
- Verify CSS selectors are correct (use browser dev tools to confirm)
- Clear cache after configuration changes: `drush cr`
