/**
 * @file
 * JavaScript behaviors for the Print This Page module.
 */

(function (Drupal) {
  Drupal.behaviors.printThisPage = {
    attach(context, settings) {
      // Add 'js-enabled' class to <html> so we can show JS-only elements
      document.documentElement.classList.add('js-enabled');

      // Create dynamic print styles for excluded elements
      const createPrintStyles = (excludeList) => {
        // Remove any previously created style element
        const existingStyle = document.getElementById(
          'print-this-page-dynamic-styles',
        );
        if (existingStyle) {
          existingStyle.remove();
        }

        if (!excludeList) {
          return;
        }

        // Process the comma-separated list
        const selectors = excludeList
          .split(',')
          .map((item) => item.trim())
          .filter((item) => item.length > 0);

        if (selectors.length > 0) {
          // Create a style element
          const style = document.createElement('style');
          style.id = 'print-this-page-dynamic-styles';

          // Create print media query with selectors
          const css = `
            @media print {
              ${selectors.join(', ')} {
                display: none !important;
              }
            }
          `;

          style.appendChild(document.createTextNode(css));
          document.head.appendChild(style);
        }
      };

      // Create print styles on page load
      const excludeList = settings.printThisPage?.excludeList || '';
      createPrintStyles(excludeList);

      // Use data-print-attached to ensure this runs only once per page load
      const elements = context.querySelectorAll(
        '#print-this-page-link:not([data-print-attached])',
      );
      elements.forEach(function (el) {
        el.setAttribute('data-print-attached', 'true');

        el.addEventListener('click', function (e) {
          // Prevent default link action
          e.preventDefault();

          // Call analytics event before printing
          if (typeof window.dataLayer !== 'undefined') {
            window.dataLayer.push({
              event: 'print_button_clicked',
              page_title: document.title,
              page_location: window.location.href,
            });
          }

          // Trigger the print dialog
          window.print();
        });
      });
    },
  };
})(Drupal);
