<?php

namespace Drupal\print_this_page\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Print This Page' block.
 *
 * @Block(
 *   id = "print_this_page_block",
 *   admin_label = @Translation("Print This Page"),
 *   category = @Translation("Custom"),
 * )
 */
class PrintThisPageBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'link_text' => $this->t('Print this page'),
      'exclude_list' => 'header, footer, aside, nav, form, iframe, .menu',
      'show_icon' => TRUE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['link_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link Text'),
      '#description' => $this->t('The text that will be displayed for the print link.'),
      '#default_value' => $config['link_text'],
      '#required' => TRUE,
    ];

    $form['show_icon'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show print icon'),
      '#description' => $this->t('Display the print icon (🖨️) next to the link text.'),
      '#default_value' => $config['show_icon'],
    ];

    $form['exclude_list'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Elements to exclude from printing'),
      '#description' => $this->t('Enter a comma-separated list of CSS selectors (IDs, classes, or element names) to hide when printing. Example: header, footer, aside, nav, form, iframe, .menu'),
      '#default_value' => $config['exclude_list'],
      '#rows' => 3,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $this->configuration['link_text'] = $form_state->getValue('link_text');
    $this->configuration['show_icon'] = $form_state->getValue('show_icon');
    $this->configuration['exclude_list'] = $form_state->getValue('exclude_list');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();

    $build = [
      '#theme' => 'print_this_page_button',
      '#link_text' => $config['link_text'],
      '#show_icon' => $config['show_icon'],
      '#attached' => [
        'library' => [
          'print_this_page/print-button',
        ],
        'drupalSettings' => [
          'printThisPage' => [
            'excludeList' => $config['exclude_list'],
          ],
        ],
      ],
      '#cache' => [
        'contexts' => ['url'],
      ],
    ];

    return $build;
  }

}
