<?php

namespace Drupal\Tests\print_this_page\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\print_this_page\Plugin\Block\PrintThisPageBlock;

/**
 * Kernel tests for the Print This Page module.
 *
 * @group print_this_page
 */
class PrintThisPageKernelTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'block',
    'print_this_page',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installConfig(['system']);
  }

  /**
   * Tests that the module's theme hook is registered.
   */
  public function testThemeHookRegistration() {
    $theme_registry = \Drupal::service('theme.registry');
    $hooks = $theme_registry->get();

    $this->assertArrayHasKey('print_this_page_button', $hooks);

    $hook = $hooks['print_this_page_button'];
    $this->assertArrayHasKey('variables', $hook);
    $this->assertArrayHasKey('template', $hook);

    $variables = $hook['variables'];
    $this->assertArrayHasKey('link_text', $variables);
    $this->assertArrayHasKey('show_icon', $variables);
    $this->assertArrayHasKey('module_path', $variables);
  }

  /**
   * Tests block plugin instantiation and basic functionality.
   */
  public function testBlockPluginInstantiation() {
    $block_manager = \Drupal::service('plugin.manager.block');

    $this->assertTrue($block_manager->hasDefinition('print_this_page_block'));

    $plugin_definition = $block_manager->getDefinition('print_this_page_block');
    $this->assertEquals('Print This Page', $plugin_definition['admin_label']);
    $this->assertEquals('Custom', $plugin_definition['category']);

    $block_instance = $block_manager->createInstance('print_this_page_block');
    $this->assertInstanceOf(PrintThisPageBlock::class, $block_instance);

    // Test that the block can build successfully.
    $build = $block_instance->build();
    $this->assertIsArray($build);
    $this->assertEquals('print_this_page_button', $build['#theme']);
  }

  /**
   * Tests field formatter plugin registration.
   */
  public function testFieldFormatterRegistration() {
    $formatter_manager = \Drupal::service('plugin.manager.field.formatter');

    $this->assertTrue($formatter_manager->hasDefinition('print_this_page'));

    $plugin_definition = $formatter_manager->getDefinition('print_this_page');
    $this->assertEquals('Print This Page', $plugin_definition['label']);

    $expected_field_types = [
      'boolean',
      'string',
      'text',
      'text_long',
      'text_with_summary',
      'entity_reference',
    ];

    $this->assertEquals($expected_field_types, $plugin_definition['field_types']);
  }

  /**
   * Tests module's help hook with actual services.
   */
  public function testModuleHelp() {
    /** @var \Drupal\Core\Routing\RouteMatchInterface $route_match */
    $route_match = \Drupal::service('current_route_match');

    // Test with correct route name.
    $result = print_this_page_help('help.page.print_this_page', $route_match);

    // The function should return a string or NULL based on file existence.
    $this->assertTrue(is_string($result) || is_null($result));

    // Test with incorrect route name.
    $result = print_this_page_help('some.other.route', $route_match);
    $this->assertNull($result);
  }

  /**
   * Tests the theme preprocess function.
   */
  public function testThemePreprocess() {
    $variables = [];
    template_preprocess_print_this_page_button($variables);

    $this->assertArrayHasKey('module_path', $variables);
    $this->assertStringStartsWith('/', $variables['module_path']);
    $this->assertStringContainsString('print_this_page', $variables['module_path']);
  }

}
